<?php
/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the "id" fields, make sure to use all lowercase and no spaces.
 *  
 */

function optionsframework_options() {
	
	// Pull all Google Fonts using API into an array
	require ( MTHEME_PARENTDIR . '/framework/options/google-fonts.php');
	//$fontArray = unserialize($fontsSeraliazed);
	$google_font_array = json_decode ($google_api_output,true) ;
	//print_r( json_decode ($google_api_output) );
	
	$items = $google_font_array['items'];

	$home_b1_status=" - (empty)";
	$home_b2_status=" - (empty)";
	$home_b3_status=" - (empty)";
	$home_b4_status=" - (empty)";
	if (of_get_option('home_custom_block1')!="" ) $home_b1_status ="";
	if (of_get_option('home_custom_block2')!="" ) $home_b2_status ="";
	if (of_get_option('home_custom_block3')!="" ) $home_b3_status ="";
	if (of_get_option('home_custom_block4')!="" ) $home_b4_status ="";
	
	$sidebar_message="Enter a name to active sidebar";
	
	$options_fonts=array();
	array_push($options_fonts, "Default Font");
	$fontID = 0;
	foreach ($items as $item) {
		$fontID++;
		$variants='';
		$variantCount=0;
		foreach ($item['variants'] as $variant) {
			$variantCount++;
			if ($variantCount>1) { $variants .= '|'; }
			$variants .= $variant;
		}
		$variantText = ' (' . $variantCount . ' Varaints' . ')';
		if ($variantCount <= 1) $variantText = '';
		$options_fonts[ $item['family'] . ':' . $variants ] = $item['family']. $variantText;
	}

	
	// Pull all the categories into an array
	$options_categories = array(); 
	array_push($options_categories, "All Categories");
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}
	
	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	if ($options_pages_obj) {
		foreach ($options_pages_obj as $page) {
			$options_pages[$page->ID] = $page->post_title;
		}
	}
	
	// Pull all the Featured into an array
	$featured_pages = get_posts('post_type=mtheme_featured&orderby=title&numberposts=-1&order=ASC');
	if ($featured_pages) {
		foreach($featured_pages as $key => $list) {
			$custom = get_post_custom($list->ID);
			if ( isset($custom["fullscreen_type"][0]) ) { 
				$slideshow_type=' ('.$custom["fullscreen_type"][0].')'; 
			} else {
			$slideshow_type="";
			}
			$options_featured[$list->ID] = $list->post_title . $slideshow_type;
		}
	} else {
		$options_featured[0]="Featured pages not found.";
	}
	
	// Pull all the Featured into an array
	$bg_slideshow_pages = get_posts('post_type=mtheme_featured&orderby=title&numberposts=-1&order=ASC');
	if ($bg_slideshow_pages) {
		foreach($bg_slideshow_pages as $key => $list) {
			$custom = get_post_custom($list->ID);
			if ( isset($custom["fullscreen_type"][0]) ) { 
				$slideshow_type=$custom["fullscreen_type"][0]; 
			} else {
			$slideshow_type="";
			}
			if ($slideshow_type<>"Fullscreen-Video") {
				$options_bgslideshow[$list->ID] = $list->post_title;
			}
		}
	} else {
		$options_bgslideshow[0]="Featured pages not found.";
	}
	
	// Pull all the Portfolio into an array
	$portfolio_pages = get_posts('post_type=mtheme_portfolio&orderby=title&numberposts=-1&order=ASC');
	if ($portfolio_pages) {
		foreach($portfolio_pages as $key => $list) {
			$custom = get_post_custom($list->ID);
			$portfolio_list[$list->ID] = $list->post_title;
		}
	}

	// Pull all the Portfolio Categories into an array
	$the_list = get_categories('taxonomy=types&title_li=');
	
	if ($the_list) {
		$portfolio_categories=array();
		$portfolio_categories[0]="All the items";
		foreach($the_list as $key => $list) {
			$portfolio_categories[$list->slug] = $list->name;
		}
	} else {
		$portfolio_categories[0]="Portfolio Categories not found.";
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/framework/options/images/';
	$theme_imagepath =  get_template_directory_uri() . '/images/';
		
	$options = array();
		
$options[] = array( "name" => __("تنظیمات عمومی"),
	"sectionID" => "main-section",
	"type" => "heading");
	
	$options[] = array(  
		"name" => __("استایل قالب"),
		"desc" => __("انتخاب نوع قالب تیره یا روشن"),
		"id" => "theme_style",
		"std" => 'default',
		"options" => array(
			"light" => "روشن",
			"dark" => "تیره",
		),
		"type" => "select"
	);
	
	$options[] = array(  
		"name" => __("نوع صفحه اصلی"),
		"desc" => __("در این قسمت شما می توانید نوع صفحه اصلی خود را تغییر . 2 حالت پیش فرض و وبلاگ دارد که در حال وبلاگ اسلاید شو به همراه لیستی از پست های شما نمایش داده می شود"),
		"id" => "mainpage_type",
		"std" => 'default',
		"options" => array(
			"default" => "حالت پیش فرض",
			"bloglist" => "وبلاگ",
		),
		"type" => "select"
	);
	
	$options[] = array(  
		"name" => __("پست الکترونیک فرم تماس"),
		"desc" => __("ایمیل برای فرم تماس.ابتدا شما نیاز دارید یک صفجه برای فرم تماس ایحاد کنید بعد از ساختن صفحه این ایمیل در کنار نقشه نمایش داده می شود"),
		"id" => "email",
		"std" => "",
		"size" => '40',
		"type" => "text"
	);
	
$options[] = array( "name" => "1- پس زمینه",
	"sectionID" => "theme-skinsettings-section",
	"type" => "heading");

	$options[] = array(  
		"name" => __("الگوی پس زمینه"),
		"desc" => __("تنظیم پس زیمینه برای قالب شما.شما می توانید یک الگو یا بافت برای پر کردن پس زمینه خود انتخاب کنید .الگو ها شفاف هستند و می تواند با انتخاب یک رنگ تر کیب شود و الگوی پس زمینه بارنگ دلخواه شما ترکیب شود"),
		"id" => "theme_bg_pattern",
		"std" => 'none',
		"options" => array(
			"none" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/none.png',
			"pattern1.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern1.png',
			"pattern2.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern2.png',
			"pattern3.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern3.png',
			"pattern4.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern4.png',
			"pattern5.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern5.png',
			"pattern6.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern6.png',
			"pattern7.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern7.png',
			"pattern8.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern8.png',
			"pattern9.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern9.png',
			"pattern10.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern10.png',
			"pattern11.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern11.png',
			"pattern12.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern12.png',
			"pattern13.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern13.png',
			"pattern14.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern14.png',
			"pattern15.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern15.png',
			"pattern16.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern16.png',
			"pattern17.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern17.png',
			"pattern18.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern18.png',
			"pattern19.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern19.png',
			"pattern20.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern20.png',
			"pattern21.png" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/pattern21.png',
			"darkwood.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/darkwood.png',
			"wood.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/wood.png',
			"grains1.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/grains1.png',
			"rainbow.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/rainbow.png',
			"sand.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/sand.png',
			"metal1.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/metal1.png',
			"metal2.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/metal2.png',
			"paint1.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/paint1.png',
			"paint2.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/paint2.png',
			"paint3.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/paint3.png',
			"paint4.jpg" =>  MTHEME_PATH . '/images/backgrounds/thumbnails/paint4.png',
		),
		"type" => "images"
	);
	

	$options[] = array(
		"name" => __("رنگ پس زمینه"),
		"desc" => __("تنظیم رنگ پس زیمنه 	برای قالب شما شما می توانید یک رنگ برای پس زمینه بدون هیچ الگو یا بافتی انتخاب کنید"),
		"id" => "theme_bg_color",
		"std" => "",
		"type" => "color"
	);
	
$options[] = array( "name" => "2- تنظیمات لوگو",
	"sectionID" => "head-logo-section",
	"type" => "heading");

	$options[] = array(
		"name" => __("لوگوی دلخواه"),
		"desc" => __("برای قالب خود یک لوگو آپلود کنید"),
		"id" => "logo",
		"std" => "",
		"type" => "upload"
	);
	
	$options[] = array(
		"name" => __("فضای بالای لوگو"),
		"desc" => __("تنظیم فاصله لوگو از سمت بالا"),
		"id" => "logo_top_spacing",
		"min" => "0",
		"max" => "100",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "50",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("فضای سمت چپ لوگو"),
		"desc" => __("تنظیم فاصله لوگو از سمت چپ ( بهترین حالت روی px 50 )"),
		"id" => "logo_left_spacing",
		"min" => "0",
		"max" => "100",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "40",
		"type" => "text"
	);
	
$options[] = array( "name" => "3- تنظیمات فونت",
	"sectionID" => "head-font-section",
	"type" => "heading");

	$options[] = array(
		"name" => __("تعویض Cufon فونت"),
		"desc" => __("تعویض فونت Cufon  در سراسر قالب . "),
		"id" => "cufon_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(
		"name" =>"عنوان فونت",
		"desc" => __("انتخاب از فونت های Cufon بالا"),
		"id" => "theme_font",
		"std" => 'cabin',
		"options" => array(
			"cabin" => MTHEME_PATH . "/js/font/samples/cabin.png",
			"pacifico" => MTHEME_PATH . "/js/font/samples/pacifico.png",
			"singlet" => MTHEME_PATH . "/js/font/samples/singlet.png",
			"indieflower" => MTHEME_PATH . "/js/font/samples/indieflower.png",
			"raleway" => MTHEME_PATH . "/js/font/samples/raleway.png",
			"pt_sans" =>  MTHEME_PATH . "/js/font/samples/pt_sans.png",
			"waitingforthesun" => MTHEME_PATH . "/js/font/samples/waitingforthesun.png",
			"playfair" => MTHEME_PATH . "/js/font/samples/playfair.png",
			"holtwood" => MTHEME_PATH . "/js/font/samples/holtwood.png",
			"open_sans" =>  MTHEME_PATH . "/js/font/samples/open_sans.png",
			"artifika" =>  MTHEME_PATH . "/js/font/samples/artifika.png",
			"paytone" => MTHEME_PATH . "/js/font/samples/paytone.png",
			"limelight" => MTHEME_PATH . "/js/font/samples/limelight.png",
			"quicksand" => MTHEME_PATH . "/js/font/samples/quicksand.png",
			"imperator" => MTHEME_PATH . "/js/font/samples/imperator.png",
			"titillium" => MTHEME_PATH . "/js/font/samples/titillium.png",
			"vegur" => MTHEME_PATH . "/js/font/samples/vegur.png",
			"luna" => MTHEME_PATH . "/js/font/samples/luna.png",
			"greyscale" => MTHEME_PATH . "/js/font/samples/grayscale.png",
			"chunkfive" => MTHEME_PATH . "/js/font/samples/chunkfive.png",
			"sansation" => MTHEME_PATH . "/js/font/samples/sansation.png",
			"oswald" => MTHEME_PATH . "/js/font/samples/oswald.png",
			"segan" => MTHEME_PATH . "/js/font/samples/segan.png",
			"custom_font" => MTHEME_PATH . "/js/font/samples/custom.png",
		),
		"type" => "images"
	);
	
	$options[] = array(  
		"name" => __("فونت Cufon دلخواه با فرمت JS"),
		"desc" => __("شما می توانید http://cufon.shoqolate.com/generate/ برای تولید فونت cufon خود را برای تم استفاده کنید. شما پس از ایجاد یک فونت cufon  می توانید آپلود  خود را اینجا وارد کنید."),
		"id" => "custom_theme_font",
		"std" => "",
		"type" => "upload"
	);
	
$options[] = array( "name" => "4- لینک شبکه های اجتماعی",
	"sectionID" => "head-social-section",
	"type" => "heading");

	$options[] = array(
		"name" => __("خاموش کردن این بخش"),
		"desc" => __("حاموش کردن بخش لینک شبکه های اجتماعی"),
		"id" => "section_social_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => __("لینک تصویر شبکه اجتماعی 1"),
		"desc" => __("آپلود تصویر برای لینک شبکه اجتماعی ابعاد ایده آل برای این قسمت 16 در 16 پیکسل می باشد"),
		"id" => "icon_image_1",
		"std" => MTHEME_PATH . "/images/socialheader/twitter.png",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("نام شبکه اجتماعی"),
		"id" => "tooltip_text_1",
		"std" => "Twitter",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک شبکه اجتماعی"),
		"id" => "target_link_1",
		"std" => "#",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("لینک تصویر شبکه اجتماعی 2"),
			"desc" => __("تصویر"),
			"id" => "icon_image_2",
			"std" => "",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("نام شبکه اجتماعی "),
			"id" => "tooltip_text_2",
			"std" => "",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک شبکه اجتماعی"),
			"id" => "target_link_2",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
	$options[] = array(  
		"name" => __("لینک تصویر شبکه اجتماعی 3"),
		"desc" => __("تصویر"),
		"id" => "icon_image_3",
		"std" => "",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("نام شبکه اجتماعی"),
		"id" => "نام شبکه اجتماعی",
		"std" => "",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک شبکه اجتماعی"),
		"id" => "target_link_3",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("لینک تصویر شبکه اجتماعی 4"),
			"desc" => __("تصویر"),
			"id" => "icon_image_4",
			"std" => "",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("نام شبکه اجتماعی"),
			"id" => "tooltip_text_4",
			"std" => "",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک شبکه اجتماعی"),
			"id" => "target_link_4",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
	$options[] = array(  
		"name" => __("لینک تصویر شبکه اجتماعی 5"),
		"desc" => __("تصویر"),
		"id" => "icon_image_5",
		"std" => "",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("نام شبکه اجتماعی"),
		"id" => "tooltip_text_5",
		"std" => "",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک شبکه اجتماعی"),
		"id" => "target_link_5",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("لینک تصویر شبکه اجتماعی 6"),
			"desc" => __("تصویر"),
			"id" => "icon_image_6",
			"std" => "",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("نام شبکه اجتماعی"),
			"id" => "tooltip_text_6",
			"std" => "",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("Target link path #6"),
			"id" => "target_link_6",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
	$options[] = array(  
		"name" => __("لینک تصویر شبکه اجتماعی 7"),
		"desc" => __("تصویر"),
		"id" => "icon_image_7",
		"std" => "",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("نام شبکه اجتماعی"),
		"id" => "tooltip_text_7",
		"std" => "",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک شبکه اجتماعی"),
		"id" => "target_link_7",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("لینک تصویر شبکه اجتماعی 8"),
			"desc" => __("تصویر"),
			"id" => "icon_image_8",
			"std" => "",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("نام شبکه اجتماعی"),
			"id" => "tooltip_text_8",
			"std" => "",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک شبکه اجتماعی"),
			"id" => "target_link_8",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
	$options[] = array(  
		"name" => __("لینک تصویر شبکه اجتماعی 9"),
		"desc" => __("تصویر"),
		"id" => "icon_image_9",
		"std" => "",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("نام شبکه اجتماعی"),
		"id" => "tooltip_text_9",
		"std" => "",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک شبکه اجتماعی"),
		"id" => "target_link_9",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("لینک تصویر شبکه اجتماعی 10"),
			"desc" => __("تصویر"),
			"id" => "icon_image_10",
			"std" => "",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("نام شبکه اجتماعی"),
			"id" => "tooltip_text_10",
			"std" => "",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک شبکه اجتماعی"),
			"id" => "target_link_10",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
$options[] = array( "name" => "5- اسلاید شو",
	"sectionID" => "featured-section",
	"type" => "heading");

	$options[] = array(
		"name" => __("خاموش کردن این بخش"),
		"help" => __("Toggle section On and Off from the homepage"),
		"id" => "section_featured_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => __("نوع اسلاید شو"),
		"desc" => __("انتخاب یک سبک از اسلایدشو برای صفحه اصلی"),
		"id" => "featured_slide_type",
		"std" => 'showcase',
		"options" => array(
			"showcase" => "showcase ",
			"nivoslides" => "Nivo",
			"accordion" => "accordion",
			"video" => "video ",
			"image" => "Static image",
		),
		"type" => "select"
	);
	
$options[] = array(  "name" => " 6- showcase ",
	"sectionID" => "featured-showcase",
	"type" => "heading");
	
	$options[] = array(
		"name" => __("اجرای خودکار"),
		"desc" => __("Toggle section On and Off from the homepage"),
		"desc" => __("تنظیم خودکار برای اسلاید شو showcase "),
		"id" => "featured_showcase_autoplay",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(  
		"name" => __("موقعیت تصویر بند انگشتی"),
		"desc" => __("نمایش  تصویر بند انگشتی در بالا و پایین اسلایدشو"),
		"id" => "featured_showcase_thumbnail",
		"std" => 'outside-last',
		"options" => array(
			"outside-last" => "پایین",
			"outside-first" => "بالا",
		),
		"type" => "select"
	);
	
	$options[] = array(
		"name" => __("ارتفاع تصویر"),
		"desc" => __("تنظیم ارتفاع تصویر در واحد پیکسل"),
		"id" => "featured_showcase_height",
		"min" => "400",
		"max" => "900",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "530",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("نمایش پیکان"),
		"desc" => __("نمایش فلش ناوبری برای حرکت اسلاید."),
		"id" => "featured_showcase_arrows",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش عنوان"),
		"desc" => __("نمایش عنوان بر روی اسلاید."),
		"id" => "featured_showcase_title",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش توضیحات"),
		"desc" => __("نمایش توضیحات بر روی اسلاید."),
		"id" => "featured_showcase_desc",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(  
		"name" => __("نوع انتقال"),
		"desc" => __("نوع انتفال به دلخواه ، در هر دو صورت افقی، عمودی و یا محو شدن اسلاید."),
		"id" => "featured_showcase_transition",
		"std" => 'hslide',
		"options" => array(
			"hslide" => "اسلاید افقی",
			"vslide" => "اسلاید عمودی",
			"fade" => "محو شدن اسلاید",
		),
		"type" => "select"
	);
	
	$options[] = array(
		"name" => __("سرعت انتقال "),
		"desc" => __("سرعت انتقال از هر اسلاید."),
		"id" => "featured_showcase_transitionspeed",
		"min" => "200",
		"max" => "5000",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "500",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("تاخیر بین انتقال"),
		"help" => __("Delay between slides transition."),
		"desc" => __("تاخیر بین انتقال اسلاید."),
		"id" => "featured_showcase_transitiondelay",
		"min" => "2500",
		"max" => "10000",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "3000",
		"type" => "text"
	);
	
$options[] = array(  "name" => " 7- Nivo",
	"sectionID" => "featurednivo-section",
	"type" => "heading");
	
	$options[] = array(
		"name" => __("اجرای خودکار"),
		"help" => __("Switch On / Off autoplay for Nivo featured slides."),
		"desc" => __("تنظیم خودکار برای اسللاید شو Nivo"),
		"id" => "featured_nivo_autoplay",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش عنوان"),
		"help" => __("Toggle titles on Nivo slides"),
		"desc" => __("نمایش عنوان بر روی اسلاید."),
		"id" => "featured_nivo_title",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش توضیحات"),
		"help" => __("Toggle descrriptions on Nivo Slides"),
		"desc" => __("نمایش توضیحات بر روی اسلاید"),
		"id" => "featured_nivo_desc",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(  
		"name" => __("استایل انتقال"),
		"help" => __("Transition type for the nivo slides"),
		"desc" => __("نوع انتقال هر اسلاید"),
		"id" => "featured_nivo_transition_style",
		"std" => 'boxRain',
		"options" => array(
			"random" => "random",
			"sliceDown" => "sliceDown",
			"fold" => "fold",
			"fade" => "fade",
			"sliceUp" => "sliceUp",
			"sliceUpLeft" => "sliceUpLeft",
			"sliceUpDown" => "sliceUpDown",
			"sliceDownLeft" => "sliceDownLeft",
			"sliceUpDownLeft" => "sliceUpDownLeft",
			"slideInRight" => "slideInRight",
			"slideInLeft" => "slideInLeft",
			"boxRandom" => "boxRandom",
			"boxRain" => "boxRain",
			"boxRainReverse" => "boxRainReverse",
			"boxRainGrow" => "boxRainGrow",
			"boxRainGrowReverse" => "boxRainGrowReverse"
		),
		"type" => "select"
	);
	
	$options[] = array(
		"name" => __("سرعت انتقال"),
		"help" => __("Transition speed from one slide to the other."),
		"desc" => __("تنظیم سرعت انتقال برای اسلایدشو Nivo"),
		"id" => "featured_nivo_transition_speed",
		"min" => "100",
		"max" => "1000",
		"step" => "100",
		"unit" => 'seconds',
		"std" => "500",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("زمان مکث"),
		"help" => __("Pause time until next transition. Active on autoplay."),
		"desc" => __("زمان مکث کردن خودکار اسلایدشو Nivo اگر گزینه خودکار روشن باشد"),
		"id" => "featured_nivo_pausetime",
		"min" => "2500",
		"max" => "10000",
		"step" => "500",
		"unit" => 'seconds',
		"std" => "5000",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("برش های اسلاید نیوو"),
		"help" => __("Number of slices for nivo slide transition."),
		"desc" => __("تعداد برش های اسلاید"),
		"id" => "featured_nivo_slices",
		"min" => "5",
		"max" => "30",
		"step" => "1",
		"unit" => 'seconds',
		"std" => "15",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("ستون باکس"),
		"help" => __("Number of box columns used in transition box effects"),
		"desc" => __("ستون باکس برای اسلایدشو Nivo"),
		"id" => "featured_nivo_box_cols",
		"min" => "5",
		"max" => "30",
		"step" => "1",
		"unit" => 'seconds',
		"std" => "10",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("خط باکس"),
		"help" => __("Number of rows for box effect transitions."),
		"desc" => __("خط باکس برای اسلاید شو Nivo"),
		"id" => "featured_nivo_box_rows",
		"min" => "5",
		"max" => "30",
		"step" => "1",
		"unit" => 'seconds',
		"std" => "8",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("ارتفاع اسلاید نیوو"),
		"desc" => __("ارتفاع اسلاید برای بخش های اسلاید Nivo"),
		"id" => "featured_nivo_height",
		"min" => "400",
		"max" => "900",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "610",
		"type" => "text"
	);
		
$options[] = array(  "name" => " 8- accordion ",
	"sectionID" => "featuredaccordion-section",
	"type" => "heading");
	
	$options[] = array(  
		"name" => __("مقدار اسلاید آکاردئون"),
		"desc" => __("تعداد اسلاید برای اسلاید شو accordion . هنگامی که شما تعداد آن را تنظیم کنید متناسب می شود با فضای اطراف"),
		"id" => "featured_accordion_qty",
		"std" => '4',
		"options" => array(
			"2" => "2",
			"3" => "3",
			"4" => "4",
			"5" => "5",
			"6" => "6",
		),
		"type" => "select"
	);
	
	$options[] = array(
		"name" => __("ارتفاع اسلاید آکاردئون"),
		"desc" => __("ارتفاع اسلاید accordion "),
		"id" => "featured_accordion_height",
		"min" => "400",
		"max" => "900",
		"step" => "0",
		"unit" => 'pixels',
		"std" => "600",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("نمایش عنوان"),
		"help" => __("Dsiplay titles for the accordion"),
		"desc" => __("نمایش عنوان برای اسلاید شو accordion"),
		"id" => "featured_accordion_title",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش توضیحات"),
		"help" => __("نمایش توضیحات برای اسلاید شو accordion"),
		"desc" => __("Display descriptions"),
		"id" => "featured_accordion_desc",
		"std" => 1,
		"type" => "checkbox"
	);
	
$options[] = array(  "name" => " 9- Video",
	"sectionID" => "featured-static-section",
	"type" => "heading");
	
	$options[] = array(  
		"name" => __("کد قراردادن ویدیو برای بلوک استاتیک ویدئو"),
		"desc" => __("شما می توانید کد embed  ویدیو خود را در این قسمت قرار دهید. Vimeo ، youtube یا هر سایت اشتراک گذاری ویدیو . عرض مناسب برای این قسمت 960 پیکسل و ارتفاع آن هر چیزی می تواند باشد"),
		"id" => "featured_video",
		"std" => "",
		"cols" => '70',
		"rows" => '10',
		"type" => "textarea"
	);
		
$options[] = array( "name" => "10- بخش A",
	"sectionID" => "home-section-a",
	"type" => "heading");

	$options[] = array(
		"name" => __("نمایش این بخش"),
		"desc" => __("بخش اول در صفحه اصلی . شما می توانید سه ستون و یا کمتر را در این قسمت تنظیم کنید. عنوان ، توضیحات و لینک بخش های قابل استفاده در این قسمت هستند"),
		"id" => "section_a_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => __("ستون A"),
		"desc" => __("تصویر"),
		"id" => "sa_col_a_icon",
		"std" => MTHEME_PATH . "/images/numbers/step_one.png",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("Title"),
		"id" => "sa_col_a_title",
		"std" => "Customize",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("توضیحات "),
		"id" => "sa_col_a_desc",
		"std" => "Donec nec justo eget felis facilisis fermentum. Aliquam porttitor mauris sit amet orci.",
		"cols" => '70',
		"rows" => '5',
		"type" => "textarea"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک"),
		"id" => "sa_col_a_link",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("ستون B"),
			"desc" => __("تصویر"),
			"id" => "sa_col_b_icon",
			"std" => MTHEME_PATH . "/images/numbers/step_two.png",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("Title"),
			"id" => "sa_col_b_title",
			"std" => "Extensible",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("توضیحات"),
			"id" => "sa_col_b_desc",
			"std" => "Donec nec justo eget felis facilisis fermentum. Aliquam porttitor mauris sit amet orci.",
			"cols" => '70',
			"rows" => '5',
			"type" => "textarea"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک"),
			"id" => "sa_col_b_link",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
	$options[] = array(  
		"name" => __("ستون C"),
		"desc" => __("تصویر"),
		"id" => "sa_col_c_icon",
		"std" => MTHEME_PATH . "/images/numbers/step_three.png",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("Title"),
		"id" => "sa_col_c_title",
		"std" => "Support",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("توضیحات"),
		"id" => "sa_col_c_desc",
		"std" => "Donec nec justo eget felis facilisis fermentum. Aliquam porttitor mauris sit amet orci.",
		"cols" => '70',
		"rows" => '5',
		"type" => "textarea"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک"),
		"id" => "sa_col_c_link",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);

$options[] = array( "name" => "11- بخش B",
	"sectionID" => "home-section-b",
	"type" => "heading");

	$options[] = array(
		"name" => __("نمایش این بخش"),
		"desc" => __("برای خاموش و روشن کردن بخش دوم از این قسمت استفاده می کنیم. شما می توانید عنوان خوش آمد گویی و یا متن دکمه را تغییر دهید"),
		"id" => "section_b_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => __("عنوان خوش آمدید"),
		"desc" => __("عنوان خوش آمدید برای صفحه اصلی. این می تواند  تبریک مهم در صفحه اصلی باشد"),
		"id" => "welcome_title",
		"std" => "Catalyst premium is an powerful theme to showcase your portfolio",
		"size" => '80',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __("زیرنویس خوش آمدید"),
		"desc" => __("زیرنویس به همراه  عنوان خوش آمدید."),
		"id" => "welcome_subtitle",
		"std" => "Build and display your portfolio and creative works in a simple yet powerful theme",
		"size" => '80',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __("متن دکمه"),
		"help" => __("Text that will appear on the button"),
		"desc" => __("متن را وارد کنید تا بر روی دکمه نمایش داده شود"),
		"id" => "button_text",
		"std" => "Purchase",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __("لینک دکمه"),
		"help" => __("Link for the button."),
		"desc" => __("لینک برای استفاده در دکمه"),
		"id" => "button_link",
		"std" => "#",
		"size" => '40',
		"type" => "text"
	);
	
$options[] = array( "name" => "12- بخش C",
	"sectionID" => "home-section-c",
	"type" => "heading");

	$options[] = array(
		"name" => __("نمایش این بخش"),
		"help" => __("Display this section from the home page"),
		"desc" => __("نمایش  بخش سوم از صفحه اصلی"),
		"id" => "section_c_status",
		"std" => 1,
		"type" => "checkbox"
		
	);

	$options[] = array(  
		"name" => __("بخش اصلی اسلاید شو چرخشی"),
		"desc" => __("انتخاب صفحه یا دسته بندی یا پست ها برای استفاده در اسلایدشو چرخشی. اگر شما صفحات را انتخاب کنید شما یک صفحه با فایل پیوست در تصویر منتشر شده نیاز دارید "),
		"id" => "sc_carousel_from",
		"std" => 'pages',
		"options" => array(
			"pages" => "صفحه",
			"categories" => "دسته بندی پست ها",
			"portfolio" => "نمونه کار",
		),
		"type" => "select"
	);

	$options[] = array(
		"name" => "انتخاب صفحه",
		"desc" => __("انتخاب صفحه شما با پیوست تصویر برای اسلاید شو چرخشی"),
		"id" => "sc_carousel_page",
		"target" => 'page',
		"std" => "",
		"options" => $options_pages,
		"type" => "select",
	);
	
	$options[] = array(
		"name" => "انتخاب دسته بندی",
		"desc" => __("تصویر انتخاب شده از پست های قسمت ویژه ها گرفته می شود "),
		"id" => "sc_carousel_category",
		"target" => 'category',
		"std" => "",
		"options" => $options_categories,
		"type" => "select",
	);
	
	$options[] = array(
		"name" => "انتخاب نمونه کارها",
		"desc" => __("تصویر انتخاب شده از پست های قسمت ویژه ها گرفته می شود
"),
		"id" => "sc_carousel_portfolio",
		"target" => 'portfolio_category',
		"std" => "",
		"options" => $portfolio_categories,
		"type" => "select",
	);
	
	$options[] = array(  
		"name" => __("تعداد تصاویر"),
		"help" => __("Set a limit to the number of images shown"),
		"desc" => __("محدود کردن تصویر نمایش داده شده در اسلایدشو چرخشی را در اینجا انتخاب کنید"),
		"id" => "sc_carousel_limit",
		"std" => '-1',
		"options" => array(
			"-1" => "4",
			"1" => "3",
			"2" => "2",
			"3" => "1",
			
	
		),
		"type" => "select"
	);
	
	$options[] = array(  
		"name" => __("لینک تصاویر"),
		"help" => __("Display the linked images to either the lightbox or link directly to the respective post or page."),
		"desc" => __("چگونگی نمایش تصاویر"),
		"id" => "sc_carousel_link",
		"std" => 'lightbox',
		"options" => array(
			"lightbox" => "Lightbox",
			"direct" => "Direct",
		),
		"type" => "select"
	);
	
$options[] = array( "name" => "13- بخش D",
	"sectionID" => "home-section-d",
	"type" => "heading");

	$options[] = array(
		"name" => __("نمایش این بخش"),
		"help" => __("Toggle On / Off this section from the homepage"),
		"desc" => __("نمایش بخش چهارم از صفحه اصلی"),
		"id" => "section_d_status",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش ردیف اول"),
		"help" => __("Switch off the top row leaving the bottom three blocks visible."),
		"desc" => __("نمایش ردیف بالا از این بخش"),
		"id" => "sd_row_a_status",
		"std" => 1,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => __("نمایش ردیف دوم"),
		"help" => __("Switch off the bottom row leaving the top three blocks visible."),
		"desc" => __("نمایش ردیف پایین از این بخش"),
		"id" => "sd_row_b_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => __("ستون A ( بالا راست )"),
		"help" => __("Fill each of these blocks to display in the homepage. That is the 6 blocks which appear below the portfolio carousel"),
		"desc" => __("تصویر"),
		"id" => "sd_col_a_icon",
		"std" => MTHEME_PATH . "/images/icons/leaf.png",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("Title"),
		"id" => "sd_col_a_title",
		"std" => "Advanced Options",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("توضیحات"),
		"id" => "sd_col_a_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet. ",
		"cols" => '70',
		"rows" => '5',
		"type" => "textarea"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک"),
		"id" => "sd_col_a_link",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("ستون B ( بالا وسط )"),
			"desc" => __("تصویر"),
			"id" => "sd_col_b_icon",
			"std" => MTHEME_PATH . "/images/icons/flask.png",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("Title"),
			"id" => "sd_col_b_title",
			"std" => "Multiple Portfolios",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("توضیحات"),
			"id" => "sd_col_b_desc",
			"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet. ",
			"cols" => '70',
			"rows" => '5',
			"type" => "textarea"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک"),
			"id" => "sd_col_b_link",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
		
	$options[] = array(  
		"name" => __("ستون C ( بالا چپ )"),
		"desc" => __("تصویر"),
		"id" => "sd_col_extra_a_icon",
		"std" => MTHEME_PATH . "/images/icons/controls.png",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("Title"),
		"id" => "sd_col_extra_a_title",
		"std" => "Content Objects",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("توضیحات"),
		"id" => "sd_col_extra_a_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet. ",
		"cols" => '70',
		"rows" => '5',
		"type" => "textarea"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک"),
		"id" => "sd_col_extra_a_link",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
		
		$options[] = array(  
			"name" => __("ستون A ( پایین راست )"),
			"desc" => __("تصویر"),
			"id" => "sd_col_c_icon",
			"std" => MTHEME_PATH . "/images/icons/bulb.png",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("Title"),
			"id" => "sd_col_c_title",
			"std" => "Post headers",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("توضیحات"),
			"id" => "sd_col_c_desc",
			"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet. ",
			"cols" => '70',
			"rows" => '5',
			"type" => "textarea"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک"),
			"id" => "sd_col_c_link",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);
	
	$options[] = array(  
		"name" => __("ستون B ( پایین وسط )"),
		"desc" => __("تصویر"),
		"id" => "sd_col_d_icon",
		"std" => MTHEME_PATH . "/images/icons/recycle.png",
		"type" => "upload"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("Title"),
		"id" => "sd_col_d_title",
		"std" => "Gui Shortcodes",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("توضیحات"),
		"id" => "sd_col_d_desc",
		"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet. ",
		"cols" => '70',
		"rows" => '5',
		"type" => "textarea"
	);
	
	$options[] = array(  
		"name" => __(""),
		"desc" => __("لینک"),
		"id" => "sd_col_d_link",
		"std" => "",
		"size" => '80',
		"type" => "text"
	);
	
		$options[] = array(  
			"name" => __("ستون C ( پایین چپ )"),
			"desc" => __("تصویر"),
			"id" => "sd_col_extra_b_icon",
			"std" => MTHEME_PATH . "/images/icons/mouse.png",
			"type" => "upload"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("Title"),
			"id" => "sd_col_extra_b_title",
			"std" => "Page Templates",
			"size" => '40',
			"type" => "text"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("توضیحات"),
			"id" => "sd_col_extra_b_desc",
			"std" => "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet. ",
			"cols" => '70',
			"rows" => '5',
			"type" => "textarea"
		);
		
		$options[] = array(  
			"name" => __(""),
			"desc" => __("لینک"),
			"id" => "sd_col_extra_b_link",
			"std" => "",
			"size" => '80',
			"type" => "text"
		);

$options[] = array( "name" => "14- بخش E",
	"sectionID" => "home-section-e",
	"type" => "heading");

	$options[] = array(
		"name" => __("نمایش این بخش"),
		"help" => __("Toggle this section On and Off from the homepage"),
		"desc" => __("نمایش بخش پنجم از صفحه اصلی"),
		"id" => "section_e_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => __("بخش نقل قول"),
		"help" => __("Quotation that appears at the lower most section of main page."),
		"desc" => __("توضیحات"),
		"id" => "sf_quote",
		"std" => "Lorem ipsum dolor! Sit amet, consectetur adipiscing elit. Mauris varius pharetra esit commodo consectetur adipiscing elit var pharetra ipsum dolor sit amet.",
		"cols" => '70',
		"rows" => '5',
		"type" => "textarea"
	);
	
$options[] = array(  "name" => "15- بلاگ",
	"sectionID" => "blog-section",
	"type" => "heading");

	$options[] = array(  
		"name" => __("نوع فهرست"),
		"help" => __("Show full posts or summary in blog lists"),
		"desc" => __("چگونگی نمایش لیست پست ها"),
		"id" => "blog_list_type",
		"std" => 'summary',
		"options" => array(
			"summary" => "خلاصه",
			"full" => "کامل",
		),
		"type" => "select"
	);
	
	$options[] = array(
		"name" => __("نمایش اطلاعات نویسنده"),
		"help" => __("Display author info after blog posts. You'll need to fill in the user account information with an avatar and user bio to display author information. <p><strong>Note:</strong> Make sure the bio info for the user is filled. The author info generates with the bio text</p>"),
		"desc" => __("نمایش اطلاعات نویسنده در پست های وبلاگ"),
		"id" => "authorstatus",
		"std" => 0,
		"type" => "checkbox"
	);
	
	$options[] = array(
		"name" => "سایز آواتار نویسنده",
		"help" => __("Size of avatar displayed beside the author info."),
		"desc" => "سایز آواتار برای نویسنده",
		"id" => "author_avatar_size",
		"min" => "12",
		"max" => "256",
		"step" => "2",
		"unit" => 'pixels',
		"std" => "64",
		"type" => "text"
	);
	
	$options[] = array(
		"name" => __("نمایش پست های مرتبط"),
		"help" => __("Display related posts underneath the blog posts. Related posts are generated using tags from the currently active blog post"),
		"desc" => __("پست های مرتبط بر اساس برچسب ها"),
		"id" => "relatedposts",
		"std" => 0,
		"type" => "checkbox"
	);
	
	$options[] = array(  
		"name" => __("فرمت زمان برای پست ها"),
		"help" => __("Time format for your blog posts. Either Human or Traditional. Human time will give you a date such as '12 Days ago'.<p>The traditional date structure can be modified according to your country or region from WordPress admin, otherwise default time format applies.</p>"),
		"desc" => __(""),
		"id" => "mtheme_datetime",
		"std" => 'Human',
		"options" => array(
			"Human" => "Human",
			"Traditional" => "Traditional",
		),
		"type" => "select"
	);

	$options[] = array(  
		"name" => __("متن ادامه مطلب"),
		"help" => __("Read more text displayed just below the blog summary in Blog Summary mode."),
		"desc" => __("متن ادامه مطلب پس از ارسال پیش نمایش"),
		"id" => "readmore_link",
		"std" => "Continue Reading",
		"size" => '40',
		"type" => "text"
	);
	
	$options[] = array(
		"name" => "سایز آواتار نظر ها",
		"help" => __("Comment avatar size."),
		"desc" => "Avatar Size for comments",
		"id" => "avatar_size",
		"min" => "12",
		"max" => "256",
		"step" => "2",
		"unit" => 'pixels',
		"std" => "64",
		"type" => "text"
	);
	
$options[] = array(  "name" => "16- رنگ",
	"sectionID" => "color-section",
	"type" => "heading");

	$options[] = array(
		"name" => __("صفحه"),
		"help" => __("Set page color and title colors from the following. You can use the color picker to set a color easily."),
		"desc" => __("رنگ صفحات"),
		"id" => "page_color",
		"std" => "",
		"type" => "color"
	);

	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ عنوان صفحات"),
		"id" => "page_title_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __("صفحه اصلی"),
		"help" => __("Select color for Mainpage Welcome title, subtitle and quotation"),
		"desc" => __("رنگ عنوان خوش آمدید"),
		"id" => "welcome_title_color",
		"std" => "",
		"type" => "color"
	);
	$options[] = array(
		"name" => __(""),
		"desc" => __("Weclome subtitle color"),
		"id" => "welcome_subtitle_color",
		"std" => "",
		"type" => "color"
	);
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ جمله نقل قول"),
		"id" => "quotation_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __("منو"),
		"help" => __("Set menu colors, hover color, background and current page item menu colors."),
		"desc" => __("رنگ سطح منو"),
		"id" => "menu_dropdown_top_text_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ سطح منوی شناور "),
		"id" => "menu_dropdown_top_hover_text_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("Menu top level background hover color"),
		"id" => "menu_dropdown_top_hover_bg_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ پس زمینه منوی کرکره  "),
		"id" => "menu_background_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ پس زمینه منو"),
		"id" => "menu_dropdown_current_item_bg_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("Menu current item link color"),
		"id" => "menu_dropdown_current_item_text_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ لینک منوی کرکره"),
		"id" => "menu_dropdown_item_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ لینک منوی کرکره شناور"),
		"id" => "menu_dropdown_item_hover_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("Menu dropdown background hover color"),
		"id" => "menu_dropdown_hover_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __("عنوان"),
		"desc" => __("تغییر رنگ عنوان قالب"),
		"id" => "title_link_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("رنگ عنوان  شناور قالب "),
		"id" => "title_link_hover_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __("جزئیات پست"),
		"desc" => __("جزئیات ارسال (ارسال شده در دسته بندی های غیر ها، تاریخ)"),
		"id" => "post_detail",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("لینک ارسال جزئیات (ارسال شده در دسته بندی ها، نظر)"),
		"id" => "post_detail_links",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("لینک ارسال جزئیات شناور (ارسال شده در دسته بندی پیوند قراردادن موشواره، نظر)"),
		"id" => "post_detail_hover_links",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __("ادامه مطلب"),
		"desc" => __("Readmore link"),
		"id" => "readmore_link_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("Readmore link hover"),
		"id" => "readmore_hover_link_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __("نوار"),
		"desc" => __("رنگ عنوار نوار کناری"),
		"id" => "sidebar_title_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("لینک نوار کناری"),
		"id" => "sidebar_link_color",
		"std" => "",
		"type" => "color"
	);
	
	$options[] = array(
		"name" => __(""),
		"desc" => __("لینک شناور نوار کناری"),
		"id" => "sidebar_hover_link_color",
		"std" => "",
		"type" => "color"
	);
	
		
$options[] = array(  "name" => "17- تنظیمات پایین صفحه",
	"sectionID" => "footer-section",
	"type" => "heading");

	$options[] = array(  
		"name" => "نمایش ویجت پایین صفحه",
		"help" => __("This can collapse and display the footer widget spaces."),
		"desc" => "نمایش فضای ویجت پایین صفحه",
		"id" => "footer_widget_status",
		"std" => 1,
		"type" => "checkbox"
	);

	$options[] = array(  
		"name" => "اسکریپ های پایین صفحه",
		"desc" => __("منظقه نمایش اسکریپ پایین صفحه در قالب . این قسمت برای استفاده از اسکریپ هایی مانند گوگل آنالیز اسکریپ های آمار گیر و یا هر اسکریپ دیگری که در کد Body قرار دارد"),
		"id" => "footer_scripts",
		"std" => "",
		"cols" => '70',
		"rows" => '10',
		"type" => "textarea"
	);

$options[] = array( "name" => "18- خروجی",
					"type" => "heading");

	$options[] = array( "name" => "خروجی تنظیمات ( کپی  کنید ) فقط خواندنی است",
						"desc" => "انتخاب همه ، کپی و ذخیره آن در در قسمت ' وارد کردن تنظیمات ' برای استفاده ار نسخه پشتیبان تنظیمات خود .",
						"id" => "exportpack",
						"std" => '',
						"class" => "big",
						"type" => "textarea");

$options[] = array( "name" => "19- وارد کردن تنظیمات",
					"type" => "heading",
					"subheading" => 'exportpack');

	$options[] = array( "name" => "وارد کردن تنظیمات (ریختن در این قسمت و ذخیره کردن )",
						"desc" => "توجه : کپی و ریختن تنظیمات از قسمت ' خروجی تنظیمات ' برای بازگردانی به نسخه پشتیبان",
						"id" => "importpack",
						"std" => '',
						"class" => "big",
						"type" => "textarea");

	return $options;
}

?>